/*! @boldr/auth v0.1.0-alpha.1 by Steven Truesdell <steven@strues.io> */
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';

/* eslint-disable */
var cache = {};

var Storage$1 = function Storage() {
  var _this = this;

  var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, Storage);

  Object.keys(Storage.defaults).map(function (key) {
    _this[key] = opts.hasOwnProperty(key) ? opts[key] : Storage.defaults[key];
  });
};

Storage$1.defaults = {
  // localStorage, sessionStorage or custom conforming to storage API
  storage: typeof window !== 'undefined' ? window.localStorage : null
};

Storage$1.create = function (opts) {
  return new Storage$1(opts);
};

Storage$1.cache = cache;

Storage$1.prototype.cache = cache;

Storage$1.prototype.get = function (key) {
  try {
    return this.storage.getItem(key);
  } catch (e) {
    return this.cache[key];
  }
};

Storage$1.prototype.set = function (key, value) {
  try {
    this.storage.setItem(key, value);
    return value;
  } catch (e) {
    this.cache[key] = value;
    return value;
  }
};

Storage$1.prototype.remove = function (key) {
  try {
    this.storage.removeItem(key);
  } catch (e) {
    delete this.cache[key];
  }
};

var Storage = new Storage$1();

// import config from '../../../../config';
var parseJWT = function parseJWT(token) {
  if (!token) {
    return null;
  }
  var base64Url = token;
  var base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');

  var parts = base64.split('.');
  if (parts.length !== 3) {
    return null;
  }

  try {
    var headerRaw = parts[0],
        payloadRaw = parts[1],
        signatureRaw = parts[2];


    var header = JSON.parse(atob(headerRaw));
    var payload = JSON.parse(atob(payloadRaw));
    var signature = atob(signatureRaw);
    var expiredToken = isTokenExpired(payload.exp);

    // If the token is expired, remove it.
    // this forces the user to login again.
    if (expiredToken === true) {
      Storage.remove('bjwt');
      return null;
    }
    return {
      header: header,
      payload: payload,
      signature: signature
    };
  } catch (err) {
    console.error(err);
    return null;
  }
};

function isTokenExpired(exp) {
  var date = new Date(0);
  var expirationDate = date.setUTCSeconds(exp);

  return expirationDate < new Date();
}

var setToken = function setToken(token) {
  return Storage.set('bjwt', token);
};

var getToken = function getToken() {
  var asJSON = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;

  var token = Storage.get('bjwt');
  if (asJSON) {
    return parseJWT(token);
  }
  return token;
};

var removeToken = function removeToken() {
  Storage.remove('bjwt');
};

export { getToken, parseJWT, setToken, removeToken };
//# sourceMappingURL=boldr-auth.node.esmodules.js.map
